package httputil

import (
	"crypto/tls"
	"fmt"
	"github.com/spf13/cast"
	"io"
	"net/http"
	"net/url"
	"time"
)

// Get 请求  link：请求url
func HttpGet(link string, params map[string]interface{}, header map[string]interface{}) ([]byte, error) {
	client := &http.Client{Timeout: 20 * time.Second}
	//忽略https的证书
	client.Transport = &http.Transport{
		TLSClientConfig: &tls.Config{InsecureSkipVerify: true},
	}
	p := url.Values{}
	u, _ := url.Parse(link)
	if params != nil {
		for k, v := range params {
			p.Set(k, cast.ToString(v))
		}
	}

	u.RawQuery = p.Encode()
	req, err := http.NewRequest("GET", u.String(), nil)
	if err != nil {
		return nil, err
	}

	if header != nil {
		for k, v := range header {
			req.Header.Add(k, cast.ToString(v))
		}
	}

	resp, err := client.Do(req)
	if err != nil {
		return nil, err
	}
	defer resp.Body.Close()
	if resp.StatusCode != http.StatusOK {
		return nil, fmt.Errorf("%d:%s", resp.StatusCode, resp.Status)
	}
	return io.ReadAll(resp.Body)
}
